@@ -17,6 +17,7 @@
 #define DEBUG_SCANNER     0x0004        // dump all feature writes to stderr
 #define DEBUG_NO_SCANNERS 0x0008        // do not run the scanners
 #define DEBUG_DUMP_DATA   0x0010        // dump data as it is seen
+#define DEBUG_DECODING    0x0020        // debug decoders in scanner
 #define DEBUG_INFO        0x0040        // print extra info
 #define DEBUG_EXIT_EARLY  1000          // just print the size of the volume and exis 
 #define DEBUG_ALLOCATE_512MiB 1002      // Allocate 512MiB, but don't set any flags 
@@ -278,7 +279,7 @@ namespace be13 {
     uint16_t th_win;            /* window */
     uint16_t th_sum;            /* checksum */
     uint16_t th_urp;            /* urgent pointer */
-};
+} __attribute__((packed));
 /*
  * The packet_info structure records packets after they are read from the pcap library.
  * It preserves the original pcap information and information decoded from the MAC and
