@@ -57,7 +57,7 @@ feature_recorder::feature_recorder(class feature_recorder_set &fs_,
     count_(0),context_window_before(context_window_default),context_window_after(context_window_default),
     Mf(),Mr(),mhistograms(),mhistogram_limit(),
     stop_list_recorder(0),
-    file_number_(0),carve_mode(CARVE_ENCODED)
+    file_number_(0),carve_cache(),carve_mode(CARVE_ENCODED)
 {
     //std::cerr << "feature_recorder(" << name << ") created\n";
     open();                         // open if we are created
@@ -627,7 +627,7 @@ void feature_recorder::write(const pos0_t &pos0,const std::string &feature_,cons
     quote_if_necessary(feature,context);
 
     if(feature.size()==0){
-        std::cerr << "zero length feature at " << pos0 << "\n";
+        std::cerr << name << ": zero length feature at " << pos0 << "\n";
         if(debug & DEBUG_PEDANTIC) assert(0);
         return;
     }
@@ -820,6 +820,8 @@ std::string feature_recorder::carve(const sbuf_t &sbuf,size_t pos,size_t len,
         return std::string();
     }
     assert(pos < sbuf.bufsize);
+    
+
 
     /* Carve to a file depending on the carving mode.  The purpose
      * of CARVE_ENCODED is to allow us to carve JPEGs when they are
@@ -853,24 +855,40 @@ std::string feature_recorder::carve(const sbuf_t &sbuf,size_t pos,size_t len,
      * that's okay, because the second one will fail.
      */
 
-    uint64_t this_file_number = file_number_add(1);
-    std::string dirname1 = fs.get_outdir() + "/" + name;
-    std::stringstream ss;
+    sbuf_t cbuf(sbuf,pos,len);          // the buf we are going to carve
+    std::string carved_hash_hexvalue = (*fs.hasher.func)(cbuf.buf,cbuf.bufsize);
 
+    /* See if this is in the cache */
+    bool in_cache = carve_cache.check_for_presence_and_insert(carved_hash_hexvalue);
+
+
+    uint64_t this_file_number = file_number_add(in_cache ? 0 : 1); // increment if we are not in the cache
+    std::string dirname1 = fs.get_outdir() + "/" + name;
+
+    std::stringstream ss;
     ss << dirname1 << "/" << std::setw(3) << std::setfill('0') << (this_file_number / 1000);
 
     std::string dirname2 = ss.str(); 
-    std::string fname         = dirname2 + std::string("/") + valid_dosname(sbuf.pos0.str() + ext);
+    std::string fname         = dirname2 + std::string("/") + valid_dosname(cbuf.pos0.str() + ext);
     std::string fname_feature = fname.substr(fs.get_outdir().size()+1); 
-    std::string carved_hash_hexvalue = (*fs.hasher.func)(sbuf.buf,sbuf.bufsize);
 
     /* Record what was found in the feature file.
      */
+    if (in_cache){
+        fname="";             // no filename
+        fname_feature="<CACHED>";
+    }
+
+    // write to the feature file
     ss.str(std::string()); // clear the stringstream
-    ss << "<fileobject><filename>" << fname << "</filename><filesize>" << len << "</filesize>"
-       << "<hashdigest type='" << fs.hasher.name << "'>" << carved_hash_hexvalue << "</hashdigest></fileobject>";
-    this->write(sbuf.pos0+len,fname_feature,ss.str());
+    ss << "<fileobject>";
+    if (!in_cache) ss << "<filename>" << fname << "</filename>";
+    ss << "<filesize>" << len << "</filesize>";
+    ss << "<hashdigest type='" << fs.hasher.name << "'>" << carved_hash_hexvalue << "</hashdigest></fileobject>";
+    this->write(cbuf.pos0,fname_feature,ss.str());
     
+    if (in_cache) return fname;               // do not make directories or write out if we are cached
+
     /* Make the directory if it doesn't exist.  */
     if (access(dirname2.c_str(),R_OK)!=0){
 #ifdef WIN32
@@ -899,7 +917,84 @@ std::string feature_recorder::carve(const sbuf_t &sbuf,size_t pos,size_t len,
         return std::string();
     }
 
-    ssize_t ret = sbuf.write(fd,pos,len);
+    ssize_t ret = cbuf.write(fd,0,len);
+    if(ret<0){
+        std::cerr << "*** carve: Cannot write(pos=" << fd << "," << pos << " len=" << len << "): "<< strerror(errno) << "\n";
+    }
+    ::close(fd);
+    return fname;
+}
+
+/* 
+ This is based on feature_recorder::carve and append carving record to specified filename
+ */
+std::string feature_recorder::carve_records(const sbuf_t &sbuf,size_t pos,size_t len,
+                                    const std::string &filename)
+{
+    if(flags & FLAG_DISABLED) return std::string();           // disabled
+
+    if(pos >= sbuf.pagesize && pos < sbuf.bufsize){
+        return std::string();
+    }
+    assert(pos < sbuf.bufsize);
+
+    sbuf_t cbuf(sbuf,pos,len);          // the buf we are going to carve
+    std::string carved_hash_hexvalue = (*fs.hasher.func)(cbuf.buf,cbuf.bufsize);
+
+    /* See if this is in the cache */
+    bool in_cache = carve_cache.check_for_presence_and_insert(carved_hash_hexvalue);
+
+    std::string dirname1 = fs.get_outdir();
+
+    std::stringstream ss;
+    ss << dirname1;
+   
+    std::string dirname2 = ss.str(); 
+    std::string fname = dirname2 + std::string("/") + valid_dosname(filename);
+    std::string fname_feature = fname.substr(fs.get_outdir().size()+1); 
+    
+    /* Record what was found in the feature file.
+     */
+    if (in_cache){
+        fname="";             // no filename
+        fname_feature="<CACHED>";
+    }
+
+    // write to the feature file
+    ss.str(std::string()); // clear the stringstream
+    ss << len;
+    this->write(cbuf.pos0,fname_feature,ss.str());
+    
+    if (in_cache) return fname;               // do not make directories or write out if we are cached
+
+    /* Make the directory if it doesn't exist.  */
+    if (access(dirname2.c_str(),R_OK)!=0){
+#ifdef WIN32
+        mkdir(dirname1.c_str());
+        mkdir(dirname2.c_str());
+#else   
+        mkdir(dirname1.c_str(),0777);
+        mkdir(dirname2.c_str(),0777);
+#endif
+    }
+
+    int oerrno = errno;                 // remember error number
+    if (access(dirname2.c_str(),R_OK)!=0){
+        std::cerr << "Could not make directory " << dirname2 << ": " << strerror(oerrno) << "\n";
+        return std::string();
+    }
+
+    // To control multiple thread writing
+    cppmutex::lock lock(Mf);
+
+    /* Write the file into the directory */
+    int fd = ::open(fname.c_str(),O_APPEND|O_CREAT|O_BINARY|O_RDWR,0666);
+    if(fd<0){
+        std::cerr << "*** carve: Cannot create " << fname << ": " << strerror(errno) << "\n";
+        return std::string();
+    }
+
+    ssize_t ret = cbuf.write(fd,0,len);
     if(ret<0){
         std::cerr << "*** carve: Cannot write(pos=" << fd << "," << pos << " len=" << len << "): "<< strerror(errno) << "\n";
     }
