@@ -104,7 +104,7 @@ void sbuf_t::raw_dump(int fd2,uint64_t start,uint64_t len) const
     if(len>bufsize-start) len=bufsize-start; // maximum left
     uint64_t written = ::write(fd2,buf+start,len);
     if(written!=len){
-      cerr << "write: cannot write sbuf.\n";
+        std::cerr << "write: cannot write sbuf.\n";
     }
 }
 
@@ -232,11 +232,11 @@ static const char *hexbuf(char *dst,int dst_len,const unsigned char *bin,int byt
         bytes--;
         charcount++;                    // how many characters
         
-        if((flag & NSRL_HEXBUF_SPACE2) ||
-           ((flag & NSRL_HEXBUF_SPACE4) && charcount%2==0))
+        if((flag & NSRL_HEXBUF_SPACE2) || ((flag & NSRL_HEXBUF_SPACE4) && charcount%2==0)){
             *dst++ = ' ';
             *dst   = '\000';
             dst_len -= 1;
+        }
     }
     return start;                       // return the start
 }
@@ -254,7 +254,7 @@ std::ostream & operator <<(std::ostream &os,const sbuf_t &t){
 /**
  * Read the requested number of UTF-8 format string octets including any \0.
  */
-void sbuf_t::getUTF8WithQuoting(size_t i, size_t num_octets_requested, std::string &utf8_string) const {
+void sbuf_t::getUTF8(size_t i, size_t num_octets_requested, std::string &utf8_string) const {
     // clear any residual value
     utf8_string = "";
 
@@ -267,15 +267,12 @@ void sbuf_t::getUTF8WithQuoting(size_t i, size_t num_octets_requested, std::stri
         num_octets_requested = bufsize - i;
     }
     utf8_string = std::string((const char *)buf+i,num_octets_requested);
-
-    // validate or escape utf8_string
-    utf8_string = validateOrEscapeUTF8(utf8_string, true, true);
 }
 
 /**
  * Read UTF-8 format code octets into string up to but not including \0.
  */
-void sbuf_t::getUTF8WithQuoting(size_t i, std::string &utf8_string) const {
+void sbuf_t::getUTF8(size_t i, std::string &utf8_string) const {
     // clear any residual value
     utf8_string = "";
 
@@ -292,9 +289,6 @@ void sbuf_t::getUTF8WithQuoting(size_t i, std::string &utf8_string) const {
         // accept the octet
         utf8_string.push_back(octet);
     }
-
-    // validate or escape utf8_string
-    utf8_string = validateOrEscapeUTF8(utf8_string, true, true);
 }
 
 /**
@@ -318,7 +312,7 @@ void sbuf_t::getUTF16(size_t i, size_t num_code_units_requested, std::wstring &u
 
     // get code units individually
     for (size_t j = 0; j < num_code_units_requested; j++) {
-        utf16_string.push_back(get16u(i + j));
+        utf16_string.push_back(get16u(i + j*2));
     }
 }
 
