@@ -4,6 +4,8 @@
  */
 
 #include "config.h"
+#include <sys/types.h>
+#include <inttypes.h>
 #include "word_and_context_list.h"
 #include "beregex.h"
 
@@ -23,7 +25,7 @@ bool word_and_context_list::add_fc(const std::string &f,const std::string &c)
     if(c.size()>0 && context_set.find(c) != context_set.end()) return false; // already present
     context_set.insert(c);		// now we've seen it.
     fcmap.insert(std::pair<std::string,context>(f,ctx));
-    if(fcmap.size()%100==0) std::cerr << "fcmap size=" << fcmap.size()  << "\n";
+    //if(fcmap.size()%100==0) std::cerr << "fcmap size=" << fcmap.size()  << "\n";
     return true;
 }
 
