@@ -1,6 +1,8 @@
 #!/usr/bin/env python
 """idifference.
 
+DEVELOPMENT NOTE: This implementation will soon be replaced by what is currently idifference2.py, after a period of testing by users.  If idifference2.py does not meet your needs, but idifference.py does, please let one of the maintainers know (email addresses in the Git history or the python/ChangeLog file).
+
 Generates a report about what's different between two disk images.
 
 Process:
@@ -18,6 +20,7 @@ __version__ = "0.2.0rfc4"
 
 import sys,fiwalk,dfxml,time
 import copy
+import logging
 if sys.version_info < (3,1):
     raise RuntimeError("idifference.py now requires Python 3.1 or above")
 
@@ -169,6 +172,10 @@ class DiskState:
 
     def process_fi(self,fi):
         global options
+        # Filter out specific filenames create by TSK that are not of use
+        if ignore_filename(fi.filename(), self.include_dotdirs):
+            return 
+
         dprint("processing %s" % str(fi))
         
         # See if the filename changed its hash code
@@ -176,10 +183,6 @@ class DiskState:
         if not fi.allocated():
             return # only look at allocated files
 
-        # Filter out specific filenames create by TSK that are not of use
-        if ignore_filename(fi.filename(), self.include_dotdirs):
-            return 
-
         # Remember the file for the next generation
         self.new_fnames[fi.filename()] = fi
         self.new_inodes[(fi.partition(), fi.inode())] = fi
@@ -577,6 +580,8 @@ if __name__=="__main__":
 
     (options,args) = parser.parse_args()
 
+    logging.basicConfig(level=logging.DEBUG if options.debug else logging.INFO)
+
     if len(args)<1:
         parser.print_help()
         sys.exit(1)
