@@ -27,6 +27,11 @@
 #include <string>
 #include <math.h>
 
+#ifndef M_PI
+#define M_PI		3.14159265358979323846
+#endif
+
+
 class plot_view {
 public:
     plot_view() :
