@@ -89,34 +89,12 @@ void  tcpdemux::write_flow_record(const std::string &starttime,const std::string
     return theInstance;
 }
 
-
-
-/**
- * Implement a list of open_flows, each with an associated file descriptor.
- * When a new file needs to be opened, we can close a flow if necessary.
- */
-void tcpdemux::close_all_fd()
-{
-    tcpset open_flows_copy(open_flows);	// make a copy because we're going to modify it
-
-    for(tcpset::const_iterator it = open_flows_copy.begin();it!=open_flows_copy.end();it++){
-	(*it)->close_file();
-    }
-    assert(open_flows.size()==0);	// we've closed them all
-}
-
-
 /**
  * find the flow that has been written to in the furthest past and close it.
  */
 void tcpdemux::close_oldest_fd()
 {
-    tcpip *oldest_tcp=0;
-    for(tcpset::iterator it = open_flows.begin();it!=open_flows.end();it++){
-	if(oldest_tcp==0 || (*it)->last_packet_number < oldest_tcp->last_packet_number){
-	    oldest_tcp = (*it);
-	}
-    }
+    tcpip *oldest_tcp = *open_flows.begin();
     if(oldest_tcp) oldest_tcp->close_file();
 }
 
@@ -181,6 +159,7 @@ tcpip *tcpdemux::create_tcpip(const flow_addr &flowa, be13::tcp_seq isn,const be
     DEBUG(5) ("new flow %s. path: %s next seq num (nsn):%d",
               flowa.str().c_str(),new_tcpip->flow_pathname.c_str(),new_tcpip->nsn);
     flow_map[flow] = new_tcpip;
+    open_flows.reset(new_tcpip);
     return new_tcpip;
 }
 
@@ -459,6 +438,7 @@ int tcpdemux::process_tcp(const ipaddr &src, const ipaddr &dst,sa_family_t famil
 
 	if(abs(delta) > opt.max_seek){
 	    remove_flow(this_flow);
+	    delta = 0;
 	    tcp = 0;
 	}
     }
@@ -490,8 +470,18 @@ int tcpdemux::process_tcp(const ipaddr &src, const ipaddr &dst,sa_family_t famil
     /* Now tcp is valid */
     tcp->myflow.tlast = pi.ts;		// most recently seen packet
     tcp->last_packet_number = packet_counter++;
+    tcp->myflow.len += pi.pcap_hdr->len;
+    tcp->myflow.caplen += pi.pcap_hdr->caplen;
     tcp->myflow.packet_count++;
 
+    // Does not seem consitent => Print a notice
+    // See also https://stackoverflow.com/q/1491660
+    if(pi.pcap_hdr->caplen != pi.pcap_hdr->len){
+        DEBUG(2)("Captured packet has a length caplen=%d different "
+                 "from the un-truncated length len=%d provided by PCAP API",
+                 pi.pcap_hdr->caplen, pi.pcap_hdr->len);
+    }
+
     /*
      * 2012-10-24 slg - the first byte is sent at SEQ==ISN+1.
      * The first byte in POSIX files have an LSEEK of 0.
@@ -552,6 +542,8 @@ int tcpdemux::process_tcp(const ipaddr &src, const ipaddr &dst,sa_family_t famil
         if(tcp->fin_count==1){
             tcp->fin_size = (seq+tcp_datalen-tcp->isn)-1;
         }
+    } else {
+        open_flows.move_to_end(tcp);
     }
 
     /* If a fin was sent and we've seen all of the bytes, close the stream */
