@@ -3,7 +3,7 @@
  * Originally by Jeremy Elson <jelson@circlemud.org>
  * Now maintained by Simson L. Garfinkel <simsong@acm.org>
  *
- * This source code is under the GNU Public License (GPL).  
+ * This source code is under the GNU Public License (GPL).
  * See LICENSE for details.
  *
  */
@@ -87,6 +87,7 @@ void init_debug(const char *pfx,int include_pid)
 
 /****************************************************************/
 /* C++ string splitting code from http://stackoverflow.com/questions/236129/how-to-split-a-string-in-c */
+#if 0
 static std::vector<std::string> &split(const std::string &s, char delim, std::vector<std::string> &elems)
 {
     std::stringstream ss(s);
@@ -102,7 +103,7 @@ static std::vector<std::string> split(const std::string &s, char delim)
     std::vector<std::string> elems;
     return split(s, delim, elems);
 }
-
+#endif
 
 
 /* mkdir all of the containing directories in path.
@@ -171,7 +172,7 @@ void debug_real(const char *fmt, ...)
   
 
 /* Print a debugging or informatioal message, then exit  */
-void die(const char *fmt, ...) 
+[[noreturn]] void die(const char *fmt, ...)
 {
     va_list ap;
 
@@ -182,7 +183,7 @@ void die(const char *fmt, ...)
 
 /* An attempt at making signal() portable.
  *
- * If we detect sigaction, use that; 
+ * If we detect sigaction, use that;
  * otherwise if we have setsig, use that;
  * otherwise, cross our fingers and hope for the best using plain old signal().
  *
