@@ -36,7 +36,7 @@ cmd()
     echo $1
     if ! $1 ; then echo failed; exit 1; fi
 }
-NITROBA=/corp/nps/packets/2008-nitroba/nitroba.pcap
+NITROBA=nitroba.pcap
 if [ -r $NITROBA ]; then
   /bin/rm -rf out1
   cmd "$TCPFLOW -S netviz_max_histogram_size=1000 -S netviz_histogram_dump=1 -o out1 -r $NITROBA"
