@@ -45,4 +45,11 @@ testmd5()
   md5val=`openssl md5 $1 | awk '{print $2;}'`
   len=`stat -r $1  | awk '{print $8;}'`
   echo checkmd5 \"$1\" \"$md5val\" \"$len\"
-}
\ No newline at end of file
+}
+
+cmd()
+{
+    echo $1
+    if ! $1 ; then echo failed; exit 1; fi
+}
+
